@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H
+#define QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H
+
 #define QT_FEATURE_version_tagging 1
 
 #define QT_FEATURE_shared -1
@@ -61,13 +64,13 @@
 #define QT_FEATURE_test_gui 1
 
 
-#define QT_VERSION_STR "6.10.0"
+#define QT_VERSION_STR "6.10.1"
 
 #define QT_VERSION_MAJOR 6
 
 #define QT_VERSION_MINOR 10
 
-#define QT_VERSION_PATCH 0
+#define QT_VERSION_PATCH 1
 
 #define QT_COPYRIGHT "Copyright (C) The Qt Company Ltd. and other contributors."
 #if !defined(QT_SHARED) && !defined(QT_STATIC)
@@ -101,3 +104,5 @@
 #define QT_COMPILER_SUPPORTS_SHA 1
 #define QT_LINKED_OPENSSL
 #define QT_GUI_TEST 1
+
+#endif // QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_h_H
