@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
+#define QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
+
 #define QT_FEATURE_accessibility_atspi_bridge -1
 
 #define QT_FEATURE_directfb -1
@@ -160,3 +163,5 @@
 
 #define QT_FEATURE_run_opengl_tests 1
 
+
+#endif // QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
